@@ -19,7 +19,6 @@ mod message_derive;
 mod node_attribute;
 mod node_test_attribute;
 mod vault_test_attribute;
-mod vault_test_sync_attribute;
 
 /// Custom derive for the `ockam_core::AsyncTryClone` trait.
 ///
@@ -85,16 +84,21 @@ pub fn node(args: TokenStream, item: TokenStream) -> TokenStream {
 
 /// Marks an async test function to be run in an ockam node.
 ///
-/// It transforms an async input function into a test output function that sets up an ockam node and
-/// executes the body of the input function inside the node.
+/// It transforms an async input function into a test output function that sets
+/// up an ockam node and executes the body of the input function inside the
+/// node.
 ///
 /// The macro supports the following attributes:
 ///
-/// - #[ockam::test(crate = "..."]: specify a path to the crate that will be used to import the functions required
-/// by the macro. This can be helpful when using the macro from an internal `ockam` crate. Defaults to `ockam_node`.
+/// - `#[ockam::test(crate = "...")]`: specify a path to the crate that will be
+///   used to import the functions required by the macro. This can be helpful
+///   when using the macro from an internal `ockam` crate. Defaults to
+///   `ockam_node`.
 ///
-/// - #[ockam::test(timeout = 1000]: the macro executes the test with a timeout interval (in milliseconds) to avoid
-/// blocking the test indefinitely. If the test times out it will panic. Defaults to 30000 (30 seconds).
+/// - `#[ockam::test(timeout = 1000)]`: the macro executes the test with a
+///   timeout interval (in milliseconds) to avoid blocking the test
+///   indefinitely. If the test times out it will panic. Defaults to 30000 (30
+///   seconds).
 ///
 /// Example of use:
 ///
@@ -135,28 +139,6 @@ pub fn vault_test(_attr: TokenStream, item: TokenStream) -> TokenStream {
     vault_test_attribute::expand(input_fn).unwrap_or_else(to_compile_error)
 }
 
-/// Expands to a test suite for a custom implementation of the vault traits.
-///
-/// The name of the test function must match one of the functions from the `ockam_vault_test_suite` crate.
-///
-/// Example of use:
-///
-/// ```ignore
-/// use ockam_vault::SoftwareVault;
-///
-/// fn new_vault() -> SoftwareVault {
-///     SoftwareVault::default()
-/// }
-///
-/// #[ockam_macros::vault_test_sync]
-/// fn hkdf() {}
-/// ```
-#[proc_macro_attribute]
-pub fn vault_test_sync(_attr: TokenStream, item: TokenStream) -> TokenStream {
-    let input_fn = parse_macro_input!(item as ItemFn);
-    vault_test_sync_attribute::expand(input_fn).unwrap_or_else(to_compile_error)
-}
-
 fn to_compile_errors(errors: Vec<syn::Error>) -> proc_macro2::TokenStream {
     let compile_errors = errors.iter().map(syn::Error::to_compile_error);
     quote!(#(#compile_errors)*)
